==> nbgrader-0.4.0rc1.tar.gz: nbgrader-0.4.0rc1/nbgrader/tests/apps/test_nbgrader_export.py <==
import os

from os.path import join
from ...utils import remove
from .. import run_nbgrader
from .base import BaseTestApp


class TestNbGraderExport(BaseTestApp):

    def test_help(self):
        """Does the help display without error?"""
        run_nbgrader(["export", "--help-all"])

    def test_export(self, db, course_dir):
        with open("nbgrader_config.py", "a") as fh:
            fh.write("""c.NbGrader.db_assignments = [
                dict(name='ps1', duedate='2015-02-02 14:58:23.948203 PST'),
                dict(name='ps2', duedate='2015-02-02 14:58:23.948203 PST')]\n""")
            fh.write("""c.NbGrader.db_students = [dict(id="foo"), dict(id="bar")]""")

        self._copy_file(join("files", "submitted-unchanged.ipynb"), join(course_dir, "source", "ps1", "p1.ipynb"))
        self._copy_file(join("files", "submitted-unchanged.ipynb"), join(course_dir, "source", "ps2", "p1.ipynb"))
        run_nbgrader(["assign", "ps1", "--db", db])
        run_nbgrader(["assign", "ps2", "--db", db])

        self._copy_file(join("files", "submitted-changed.ipynb"), join(course_dir, "submitted", "bar", "ps1", "p1.ipynb"))
        self._copy_file(join("files", "submitted-changed.ipynb"), join(course_dir, "submitted", "foo", "ps2", "p1.ipynb"))
        run_nbgrader(["autograde", "ps1", "--db", db])
        run_nbgrader(["autograde", "ps2", "--db", db])

        run_nbgrader(["export", "--db", db])
        assert os.path.isfile("grades.csv")
        with open("grades.csv", "r") as fh:
            contents = fh.readlines()
        assert len(contents) == 5

        run_nbgrader(["export", "--db", db, "--to", "mygrades.csv"])
        assert os.path.isfile("mygrades.csv")

        remove("grades.csv")
        run_nbgrader(["export", "--db", db, "--exporter", "nbgrader.plugins.CsvExportPlugin"])
        assert os.path.isfile("grades.csv")

==> nbgrader-0.6.2.tar.gz: nbgrader-0.6.2/nbgrader/tests/apps/test_nbgrader_export.py <==
import os

from os.path import join
from ...utils import remove
from .. import run_nbgrader
from .base import BaseTestApp


class TestNbGraderExport(BaseTestApp):

    def test_help(self):
        """Does the help display without error?"""
        run_nbgrader(["export", "--help-all"])

    def test_export(self, db, course_dir):
        with open("nbgrader_config.py", "a") as fh:
            fh.write("""c.CourseDirectory.db_assignments = [
                dict(name='ps1', duedate='2015-02-02 14:58:23.948203 America/Los_Angeles'),
                dict(name='ps2', duedate='2015-02-02 14:58:23.948203 America/Los_Angeles')]\n""")
            fh.write("""c.CourseDirectory.db_students = [dict(id="foo"), dict(id="bar")]""")

        self._copy_file(join("files", "submitted-unchanged.ipynb"), join(course_dir, "source", "ps1", "p1.ipynb"))
        self._copy_file(join("files", "submitted-unchanged.ipynb"), join(course_dir, "source", "ps2", "p1.ipynb"))
        run_nbgrader(["generate_assignment", "ps1", "--db", db])
        run_nbgrader(["generate_assignment", "ps2", "--db", db])

        self._copy_file(join("files", "submitted-changed.ipynb"), join(course_dir, "submitted", "bar", "ps1", "p1.ipynb"))
        self._copy_file(join("files", "submitted-changed.ipynb"), join(course_dir, "submitted", "foo", "ps2", "p1.ipynb"))
        run_nbgrader(["autograde", "ps1", "--db", db])
        run_nbgrader(["autograde", "ps2", "--db", db])

        run_nbgrader(["export", "--db", db])
        assert os.path.isfile("grades.csv")
        with open("grades.csv", "r") as fh:
            contents = fh.readlines()
        assert len(contents) == 5

        run_nbgrader(["export", "--db", db, "--to", "mygrades.csv"])
        assert os.path.isfile("mygrades.csv")

        remove("grades.csv")
        run_nbgrader(["export", "--db", db, "--exporter", "nbgrader.plugins.CsvExportPlugin"])
        assert os.path.isfile("grades.csv")

        run_nbgrader(["export", "--db", db, "--exporter=nbgrader.tests.apps.files.myexporter.MyExporter", "--to", "foo.txt"])
        assert os.path.isfile("foo.txt")

        run_nbgrader(["export", "--db", db, "--student", "['bar']"])
        assert os.path.isfile("grades.csv")
        with open("grades.csv", "r") as fh:
            contents = fh.readlines()
        assert len(contents) == 3

        run_nbgrader(["export", "--db", db, "--assignment", "['ps1']"])
        assert os.path.isfile("grades.csv")
        with open("grades.csv", "r") as fh:
            contents = fh.readlines()
        assert len(contents) == 3

        run_nbgrader(["export", "--db", db, "--assignment", "['ps1']", "--student", "['foo']"])
        assert os.path.isfile("grades.csv")
        with open("grades.csv", "r") as fh:
            contents = fh.readlines()
        assert len(contents) == 2
